@@ -2,7 +2,7 @@
 ;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
 ;; Author:     Carsten Dominik <dominik@strw.LeidenUniv.nl>
-;; Version: 4.11
+;; Version: 4.14
 ;;
 
 ;; This file is part of GNU Emacs.
@@ -134,6 +134,8 @@ distribution.  Mixed-case symbols are convenience aliases.")
       (?a    . "\\citeauthor{%l}")
       (?A    . "\\citeauthor*{%l}")
       (?y    . "\\citeyear{%l}")))
+    (bibentry "The Bibentry package"
+      "\\bibentry{%l}")
     (harvard "The Harvard package"
      ((?\C-m . "\\cite{%l}")
       (?p    . "\\cite{%l}")
